;+
;  circle.pro - generate a filled circle
;
;   result = circle(n,m, cx,cy, radius,value,[/grey])
;
;    use the /grey flag to compute the grey pixel values on the circle boundary
;-
function circle, n,m, cx,cy, radius, value, grey=grey
  if n_elements(value) eq 0 then value = 1
  x = extend(indgen(n),0,m)
  y = extend(indgen(m),1,n)
  r = sqrt((x-cx)^2 + (y-cy)^2)
  rbar = r/radius
  a0 = (rbar lt 1.0)*value
  if (keyword_set(grey)) then begin
  	a1 = a0 + 2*shift(a0,-1,0) + 4*shift(a0,0,-1) + 8*shift(a0,-1,-1)
  	set = where((a1 gt 0) and (a1 lt 15))
  	nb = (size(set))[1]
  	subsize = 10
  	for k = 0,nb-1 do begin
  	  x0 = x[set[k]]
  	  y0 = y[set[k]]
  	  xs = (ones(subsize) ## findgen(subsize))/float(subsize) + x0
  	  ys = (findgen(subsize) ## ones(subsize))/float(subsize) + y0
  	  rs = sqrt((xs-cx)^2 + (ys-cy)^2)
  	  rsbar = rs/radius
  	  as0 = (rsbar lt 1.0)*value
  	  v = total(as0)/float(subsize)^2
  	  a0[set[k]] = v
  	endfor
;  	a2 = fix(a1 eq 15)
;  	a2 += 0.25*fix((a1 eq 1) or (a1 eq 4) or (a1 eq 8) or (a1 eq 2))
;  	a2 += 0.50*fix((a1 eq 3) or (a1 eq 12) or (a1 eq 5) or (a1 eq 10))
;  	a2 += 0.75*fix((a1 eq 7) or (a1 eq 11) or (a1 eq 14) or (a1 eq 13))
;  	return,a1
  endif
  return,a0
end
;
n = 128
a = circle(n,n,n/2,n/2,n/10.,1.0,/grey)
b = circle(n,n,n/2,n/2,n/10.,1.0)
disp,alog10(abs(ft(a))>1.e-6),'grey pixel'
disp,alog10(abs(ft(b))>1.e-6),'on off pixel'
end
